from setuptools import find_packages, setup




setup(
    name="maol",
    version="0.0.0.1",
    description="Model Assisted Object Labeling Toolkit",
    long_description_content_type="text/markdown",
    author="Matthew Sessions",
    packages=find_packages(exclude=["tests", ".github"]),
    install_requires=["PySide6"],

)
